@@ -3,13 +3,18 @@
 
 import os
 
-from .core import lineage, pair, sequence 
+from . import tl
+from . import pl
+from . import io
+
+from .core import lineage, pair, sequence
+from .core.sequence import Sequence
+from .core.pair import Pair
+from .core.lineage import Lineage
 
 from .utils import alignment, cluster, decorators, jobs, log, phylogeny, pipeline, progbar, s3, seqio, utilities
-
 from .utils import alignment as aln
 from .utils import pipeline as path
-from .utils import seqio as io
 
 from .version import __version__
 
